@@ -48,12 +48,18 @@ var Events = map[string]string{
 	"payment_intent.payment_failed":            "triggers/payment_intent.payment_failed.json",
 	"payment_intent.succeeded":                 "triggers/payment_intent.succeeded.json",
 	"payment_intent.canceled":                  "triggers/payment_intent.canceled.json",
+	"payment_link.created":                     "triggers/payment_link.created.json",
+	"payment_link.updated":                     "triggers/payment_link.updated.json",
+	"payment_intent.partially_funded":          "triggers/payment_intent.partially_funded.json",
+	"payment_intent.requires_action":           "triggers/payment_intent.requires_action.json",
 	"payment_method.attached":                  "triggers/payment_method.attached.json",
 	"payout.created":                           "triggers/payout.created.json",
 	"payout.updated":                           "triggers/payout.updated.json",
 	"plan.created":                             "triggers/plan.created.json",
 	"plan.deleted":                             "triggers/plan.deleted.json",
 	"plan.updated":                             "triggers/plan.updated.json",
+	"price.created":                            "triggers/price.created.json",
+	"price.updated":                            "triggers/price.updated.json",
 	"product.created":                          "triggers/product.created.json",
 	"product.deleted":                          "triggers/product.deleted.json",
 	"product.updated":                          "triggers/product.updated.json",
